pub struct TransformationEngine {
pub ctx: SessionContext,
}Fields
ctx: SessionContextImplementations
Sourceimpl TransformationEngine
impl TransformationEngine
pub fn new() -> Self
Sourcepub async fn register_iceberg_catalog(
&self,
catalog_name: &str,
catalog: Arc<dyn Catalog>,
) -> Result<()>
pub async fn register_iceberg_catalog( &self, catalog_name: &str, catalog: Arc<dyn Catalog>, ) -> Result<()>
Registers an Apache Iceberg catalog directly into the DataFusion query context.
Sourcepub async fn execute_sql(&self, sql: &str) -> Result<SendableRecordBatchStream>
pub async fn execute_sql(&self, sql: &str) -> Result<SendableRecordBatchStream>
Executes a SQL transform query against registered tables.
Sourcepub async fn execute_dag(
&self,
dag: &ModelDag,
project_dir: impl AsRef<Path>,
output_dir: impl AsRef<Path>,
) -> Result<DagExecutionSummary>
pub async fn execute_dag( &self, dag: &ModelDag, project_dir: impl AsRef<Path>, output_dir: impl AsRef<Path>, ) -> Result<DagExecutionSummary>
Executes a full pipeline DAG tier by tier.
Before any model SQL runs, bronze sources declared in staging frontmatter are
registered via register_bronze_sources_for_dag.